#
# spec file for package xdg-desktop-portal
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xdg-desktop-portal
Version:        1.8.0
Release:        5.3.2
Summary:        A portal frontend service for Flatpak
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://github.com/flatpak/xdg-desktop-portal
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz

BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  xmlto
BuildRequires:  pkgconfig(flatpak)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(fuse)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libgeoclue-2.0) >= 2.5.2
BuildRequires:  pkgconfig(libpipewire-0.3) >= 0.2.90
BuildRequires:  pkgconfig(libportal)
# Break cycle: we buildrequire flatpak, and flatpak has a requires on xdg-desktop-portal
#!BuildIgnore:  xdg-desktop-portal
# xdg-dfesktop-portal calls out to fusermount (in $PATH) (boo#1175899)
# document-portal/document-portal-fuse.c: char *umount_argv[] = { "fusermount", "-u", "-z", (char *) path, NULL };
Requires:       %{_bindir}/fusermount

%description
A portal frontend service for Flatpak and possibly other desktop containment frameworks.

xdg-desktop-portal works by exposing a series of D-Bus interfaces known as portals under
a well-known name (org.freedesktop.portal.Desktop) and object path (/org/freedesktop/portal/desktop).

The portal interfaces include APIs for file access, opening URIs, printing and others.

%package devel
Summary:        A portal frontend service for Flatpak -- Development files
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}

%description devel
A portal frontend service for Flatpak and possibly other desktop containment frameworks.

xdg-desktop-portal works by exposing a series of D-Bus interfaces known as portals under
a well-known name (org.freedesktop.portal.Desktop) and object path (/org/freedesktop/portal/desktop).

This package contains convenience files for developers.

%lang_package

%prep
%autosetup -p1

%build
export LANG=C.UTF-8
autoreconf -fiv
%configure \
	--enable-geoclue \
	--enable-pipewire \
	%{nil}
%make_build

%install
export LANG=C.UTF-8
%make_install
%find_lang %{name}

%post
%systemd_user_post %{name}.service xdg-document-portal.service xdg-permission-store.service

%preun
%systemd_user_preun %{name}.service xdg-document-portal.service xdg-permission-store.service

%files
%license COPYING
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/interfaces
%dir %{_datadir}/dbus-1/services
%{_datadir}/dbus-1/interfaces/*.xml
%{_datadir}/dbus-1/services/org.freedesktop.impl.portal.PermissionStore.service
%{_datadir}/dbus-1/services/org.freedesktop.portal.Desktop.service
%{_datadir}/dbus-1/services/org.freedesktop.portal.Documents.service
%{_datadir}/doc/xdg-desktop-portal/
%{_libexecdir}/xdg-desktop-portal
%{_libexecdir}/xdg-document-portal
%{_libexecdir}/xdg-permission-store
%{_userunitdir}/xdg-desktop-portal.service
%{_userunitdir}/xdg-document-portal.service
%{_userunitdir}/xdg-permission-store.service

%files devel
%{_datadir}/pkgconfig/xdg-desktop-portal.pc

%files lang -f %{name}.lang

%changelog
* Thu Jan 14 2021 fcrozat@suse.com
- Ensure systemd rpm macros are called at install/uninstall times
  for systemd user services.
- Add BuildRequires on systemd-rpm-macros.
* Thu Jan  7 2021 bjorn.lie@gmail.com
- Update to version 1.8.0:
  + openuri:
  - Allow skipping the chooser for more URL tyles
  - Robustness fixes
  + filechooser: Return the current filter
  + camera:
  - Make the client node visible
  - Don't leak pipewire proxy
  + Fix file descriptor leaks
  + Testsuite improvements
  + Updated translations.
- Changes from version 1.7.2:
  + document:
  - Reduce the use of open fds
  - Add more tests and fix issues they found
  + Fix the build with musl.
- Changes from version 1.7.1:
  + filechooser:
  - Add a "directory" option
  - Document the "writable" option
  + document: Expose directories with their proper name
- Changes from version 1.7.0:
  + testsuite improvements
  + background: Avoid a segfault
  + screencast: Require pipewire 0.3
  + document:
  - Support exporting directories
  - New fuse implementation
  + Better support for snap and toolbox
  + Updated translations.
- Drop patches fixed upstream:
  + xdg-dp-port-pipewire-3-api.patch
  + 0001-Fix-use-after-free-in-xdg_get_app_info_from_pid.patch
  + 0002-add-AssumedAppArmorLabel-key-to-D-Bus-service-files.patch
  + 0003-Fix-criticals-if-no-default-handler-for-desired-type.patch
* Fri Aug 28 2020 dfaggioli@suse.com
- Require /usr/bin/fusermount: xdg-document-portal calls out to the
  binary. Without it, files or dirs can be selected, but
  whatever is done with or in them, will not have any effect
  (boo#1175899).
* Tue Jul  7 2020 callumjfarmer13@gmail.com
- Fixes for %%_libexecdir changing to /usr/libexec
* Mon Apr  6 2020 alarrosa@suse.com
- Add patch from upstream to fix a use-after-free case:
  * 0001-Fix-use-after-free-in-xdg_get_app_info_from_pid.patch
- Add patch from upstream to add AssumedAppArmorLabel key to D-Bus
  service files to allow sandboxed processes to activate the portal
  services if the sandbox makes use of AppArmor D-Bus mediation
  rules that depend on the service's security label:
  * 0002-add-AssumedAppArmorLabel-key-to-D-Bus-service-files.patch
- Add patch from upstream to fix a null pointer usage when no
  default handler is set for desired type:
  * 0003-Fix-criticals-if-no-default-handler-for-desired-type.patch
* Fri Feb 21 2020 bjorn.lie@gmail.com
- Add xdg-dp-port-pipewire-3-api.patch: Port to use new
  pipewire-3.0 api. Following this, replace
  pkgconfig(libpipewire-2.0) with pkgconfig(libpipewire-3.0)
  BuildRequires. Also add libtool BuildRequires and pass autoreconf
  as the patch touches the buildsystem.
* Fri Jan 31 2020 alarrosa@suse.com
- Set encoding before building to fix a build error in SLE.
* Sat Jan 25 2020 dimstar@opensuse.org
- No longer recommend -lang: supplements are in use
* Fri Dec 20 2019 bjorn.lie@gmail.com
- Update to version 1.6.0:
  + tests: Adapt to libportal api changes.
- Changes from version 1.5.4:
  + background:
  - Add a signal to the impl api.
  - Rewrite the monitoring to better track when apps disappear.
  + permissions: Fix SetValue handling of GVariant wrapping. This
    is an api change.
  + openuri:
  - Add a per-type always-ask option.
  - Show the app chooser dialog less often.
  + memorymonitor: A new portal to let apps receive low memory
    warnings.
  + filetransfer: A new portal to rewrite file paths between
    sandboxes.
- Changes from version 1.5.3:
  + Add more tests.
  + location: Various fixes.
  + document portal: Monitor fuse mount.
  + openuri:
  - Only ask 3 times to use the same app.
  - Add an 'ask' option.
  + Fix build from git.
  + email: Allow multiple addresses, cc and bcc.
  + filechooser: Allow saving multiple files.
  + Update translations.
- Changes from version 1.5.2:
  + Add many more tests, using libportal.
  + gamemode: Add a pidfd-based api.
  + inhibit: Send a Response signal.
  + openuri: Add an OpenDirectory api.
  + Updated translations.
- Changes from version 1.5.1:
  + Add a portal for setting desktop backgrounds
  + Add tests.
  + Optionally use libportal (for tests).
- Changes from version 1.5.0:
  + Add a secret portal that is meant be used via libsecret inside
    the sandbox. One backend for this will live in gnome-keyring,
    others are possible.
  + Fix a file descriptor leak.
  + Reduce log spam.
  + Updated translations.
- Add pkgconfig(libportal) BuildRequires: New dependency.
* Thu Jun 13 2019 bjorn.lie@gmail.com
- Update to version 1.4.2:
  + Build fixes.
- Changes from version 1.4.1:
  + Build fixes.
- Changes from version 1.4.0:
  + Add a background & autostart portal.
  + Add a gamemode portal.
  + Add a camera portal.
  + Require pipewire 0.2.6.
  + inhibit: Track session state.
  + documents: Fix a ref-counting bug.
  + screencast:
  - Add cursor modes.
  - Memory leak fixes.
  + Updated translations.
- Add pkgconfig(json-glib-1.0) BuildRequires: New dependency.
* Wed Apr 10 2019 dimstar@opensuse.org
- BuildIgnore xdg-desktop-portal: self-requires is not needed here
  to build. Flatkpak has a (correct) dependency on
  xdg-desktop-portal, but since we don't run flatpak during build,
  but merely require its -devel package, we can break up this
  chain.
* Wed Jan 30 2019 bjorn.lie@gmail.com
- Update to version 1.2.0:
  + notification:
  - Use icon validator from flatpak.
  - Don't leave temp files around.
  + email: Validate options better.
  + inhibit: Validate options better.
  + file chooser: Add support for setting the current filter.
  + Updated translations.
- Changes from version 1.1.1:
  + Validate icons in notifications.
  + Respect lockdown settings.
  + Write back permissions for notifications to indicate portal
    use.
  + Set st_nlink in the documents portal.
  + Add infrastructure for validating options.
  + Validate email addresses.
  + Updated translations.
- Changes from version 1.1.0:
  + Add a location portal, this requires geoclue 2.5.2.
  + Add a settings portal, for desktop-wide settings like XSettings
    or kdeglobals.
  + Allow locking down printing, save-to-disk and opening uris.
  + Monitor application changes in the open uri portal.
  + Add more tests.
  + Fix a crash when xdg-desktop-portal-gtk times out (boo#1118121,
    gh#flatpak/xdg-desktop-portal#236).
- Add pkgconfig(fontconfig) and pkgconfig(flatpak) BuildRequires:
  New dependencies.
- Add pkgconfig(libgeoclue-2.0) BuildRequires and pass
  enable-geoclue to configure, build new optional location portal.
* Wed Dec 19 2018 bjorn.lie@gmail.com
- Update to version 1.0.3:
  + Fix an option name in the remote desktop portal
  + document-portal: Validate permissions and report errors
  + Fix life-cycle issues with inodes in the document portal
  + Improve the test coverage of the documents portal
  + Add a 'coverage' make target
- Changes from version 1.0.2:
  + networkmonitor: Fix several issues
  + inhibit: Add session state monitoring
- Changes from version 1.0.1:
  + networkmonitor: Add GetStatus and CanReach methods
  + Unset GTK_USE_PORTAL
  + Add a portal for moving files to the trash
  + Fix an inode leak in the document portal
- Changes from version 1.0:
  + screenshot: Add a color picker api
  + screencast: Bump the pipewire dependency to 0.2.1
  + Improve --help output
  + Small documentation improvements
- Changes from version 0.99:
  + The NetworkMonitor portal API has been changed to allow access
    control
  + The Proxy and NetworkMonitor portals only respond to requests
    from sandboxes with network access
  + The flatpak portal is now documented
- Switch to tarball releases, upstream now releases stable
  tarballs.
- Following the above, drop libtool BuildRequires and autogen.sh
  macro call.
- Add pkgconfig(libpipewire-0.2) and pass --enable-pipewire to
  configure, build screencast and screenshot support.
* Tue Jun 26 2018 bjorn.lie@gmail.com
- Update to version 0.11:
  + OpenURI:
  - Fix misleading warning when accessing the permission store
  - Don't skip the dialog based on content type if a threshold is
    set
  + document-portal:
  - Support non-O_PATH fds for adding existing files
  - Only give DELETE right if you also get WRITE rights
  - Make fd validation stricter wrt /proc/pid/fd symlink
  - Rewrite paths in data
  - Verify access right on fds
  - Add some debug spew
  + XdpAppInfo: Nicer handling of kind
  + Add support for snap packages
  + XdpAppInfo: Centralize handling of xdp_app_info_new_host ()
  + Broaden what are valid app ids to allow snap.$PKGNAME
  + README: Fix docs link
  + Don't register http: uris
  + remote-desktop: Correct device type values
  + utils:
  - Generalize XdpAppInfo with a tagged union
  - Clarify content of app_infos hash table
  - Use more constants for interactions with the dbus-daemon
  - Don't leak names whose ownership changed
  + file-chooser: Handle save-file backend failure
  + screen-cast: add missing sync request
  + documents xml: Correct flag value for as-needed-by-app
  + build: Run install-test-data-hook as intended
  + Updated translations.
* Mon Mar  5 2018 fcrozat@suse.com
- Remove BuildRequires(flatpak), it is not needed.
- Own /usr/share/dbus-1, /usr/share/dbus-1/{interfaces,services}
  which were owned by flatpak package before.
* Mon Feb 26 2018 dimstar@opensuse.org
- Use SPDX3.0 license tags and package COPYING as %%license.
* Mon Feb 26 2018 dimstar@opensuse.org
- Update to version 0.10:
  + xdg-document-portal moved here from flatpak.
  + Add a new screencast and remote desktop portal based on
    PipeWire.
- Pass --disable-pipewire to configure: pipewire has not yet been
  packaged for openSUSE.
- Add pgkconfig(fuse) BuildRequires: new dependency.
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 0.9:
  + Install pkg-config files into datadir.
  + Avoid a race in the portal APIs.
  + Change the email portal to take fds.
  + Updated translations.
* Mon Jun 26 2017 zaitor@opensuse.org
- Update to version 0.8:
  + Update po files.
- Changes from version 0.7:
  + notification: Fix copy+paste error.
  + notification: Subscribe to the right interface for signals.
  + If the random request ID creates a collision, pick a new random
    ID.
  + Add some rationale.
  + Fix a typo.
  + Update README.md.
  + OpenURI: Refuse to handle file: uris.
  + Add an OpenFile method.
  + OpenFile: Fix URI.
  + Cache entire flatpak info file for peer, not just app id.
  + Store the cached flatpak-info keyfile with the request.
  + OpenFile: Rewrite app paths in /usr and /app (and /newroot).
  + OpenFile: Ensure that passed O_PATH fd is correct.
  + Send more data to the appchooser.
  + Updated translations.
- Changes from version 0.6:
  + Remove what appears to be printing lines from a debugging
    session.
  + open-uri: Fix segfault crash when no content-type can be
    resolved.
  + account: Remove debug spew.
  + Update README.md.
  + Add an email portal.
  + Include the email portal in the docs.
  + build: No need to clean org.freedesktop.portal.Desktop.service
    twice.
  + Add a systemd user unit corresponding to the session service.
  + notifications: Add better debug and error messages.
  + device: Add more detail to error messages.
  + Handle g_variant_lookup failure.
  + Encode po/Makevars in UTF-8.
  + Initialize autofree string variable to NULL.
  + open-uri: Implement a more permissive policy for the OpenURI
    portal.
  + data: Fix typo in NetworkMonitor XML definition.
  + Updated translations.
* Sun Jan 22 2017 zaitor@opensuse.org
- Update to version 0.5:
  + notification: Support 'non-exported actions.
  + Fix issues found in testing.
  + Avoid a crash when removing notifications.
  + Add an Account portal.
  + Change the Account portal API.
  + Update README.md.
  + Add a version property to all portal interfaces.
  + Fix a refcounting snafu.
  + file chooser:
  - Always grant write permissions for save dialogs.
  - Fix reading the writable property.
  + Simplify version support.
  + Updated translations.
* Wed Jan 11 2017 zaitor@opensuse.org
- Update to version 0.4:
  + No longer rely on cgroups to find the app id.
  + Fix handling of mime type filters in the file chooser portal.
  + Updated translations.
* Thu Nov  3 2016 dimstar@opensuse.org
- Initial package, version 0.3.
